# SCREEM by c0mplh4cks

Python3 package for creating graphical user interfaces inside a terminal

### Installation from PyPi

install package by using pip
```
pip3 install screem
```
or
```
pip install screem
```


### Installation from Github

clone the repository
```
git clone https://github.com/c0mplh4cks/screem
```

move inside the directory
```
cd screem
```

install the library by running the following command
```
pip3 install .
```


### Check installation

check if the library is installed by opening python
```
python3
```

and importing the library
```
import screem
```
